@@ -10,7 +10,8 @@ TITLE = u"title"
 NAME = u"name"
 ID_STRING = u"id_string"
 SMS_KEYWORD = u"sms_keyword"
-SMS_ID = u"sms_id"
+SMS_FIELD = u"sms_field"
+SMS_OPTION = u"sms_option"
 SMS_SEPARATOR = u"sms_separator"
 SMS_ALLOW_MEDIA = u"sms_allow_media"
 SMS_DATE_FORMAT = u"sms_date_format"
